import 'package:flutter/material.dart';

import 'package:kitcod_uikit_flutter/kitcod_uikit_flutter.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Kidcod UIKit Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Kidcod UIKit Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  TextButton _profileOverview() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => UserProfileView(
                headerView: HeaderView(
                  backgroundColor: Colors.indigoAccent.withOpacity(0.1),
                  leftSideIcon: IconButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    icon: const Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black,
                    ),
                  ),
                  header: const Text(
                    "Profile Overview",
                    style: TextStyle(color: Colors.black),
                  ),
                  headerAlignment: Alignment.centerLeft,
                ),
                profileImageUrl: "https://picsum.photos/201",
                name: "Shirin Kawan",
                nameStyle: const TextStyle(
                  fontSize: 20.0,
                  fontWeight: FontWeight.bold,
                ),
                profileDetailsArray: profileDetailsArray,
                button: Button(
                  name: "Follow",
                  onPressed: () {},
                  backgroundColor: Colors.indigoAccent,
                  textStyle: const TextStyle(color: Colors.white),
                  height: 40,
                ),
                profileDetailsNameStyle: TextStyle(color: Colors.grey.shade600),
                profileDetailsValueStyle:
                    const TextStyle(fontWeight: FontWeight.bold),
                groupsList: feedGroupsArray,
                groupCardButtonColor: Colors.indigoAccent,
                groupCardButtonStyle: const TextStyle(color: Colors.white),
                groupCardMembersStyle:
                    const TextStyle(color: Colors.grey, fontSize: 12),
                groupCardTitleStyle: const TextStyle(
                    fontSize: 17,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                groupPageAboutStyle:
                    const TextStyle(fontSize: 15, color: Colors.grey),
                groupPageMembersStyle: const TextStyle(
                    fontSize: 17,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                groupPageStatusStyle:
                    const TextStyle(fontSize: 17, color: Colors.grey),
                groupPageTitleStyle: const TextStyle(
                  fontSize: 30,
                  fontWeight: FontWeight.bold,
                  color: Colors.black,
                ),
                avatarSize: 12,
                postPostedTimeStyle: const TextStyle(
                  fontSize: 15,
                  color: Colors.grey,
                ),
                postFeedTitleStyle: const TextStyle(
                    fontSize: 15,
                    color: Colors.black,
                    fontWeight: FontWeight.bold),
                postFeedDescriptionStyle:
                    const TextStyle(fontSize: 15, color: Colors.black),
                postFeedAudioTitleStyle: const TextStyle(
                    fontSize: 17,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                postNameStyle: const TextStyle(
                    fontSize: 15,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                postUserNameStyle: const TextStyle(
                    fontSize: 15,
                    color: Colors.black,
                    fontWeight: FontWeight.normal),
                postGroupTagsStyle: const TextStyle(color: Colors.indigo),
                feedPostsArray: feedPostsArray,
              ),
            ),
          );
        },
        child: const Center(child: Text("UserProfileView Screen")),
      );

  TextButton _createPost() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => CreatePost(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                    header: const Text(
                      "Create New",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                  ),
                  name: "Bilal Shahid",
                  nameStyle: const TextStyle(
                      fontSize: 15,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  userName: "@bilal_sh",
                  // userNameStyle: const TextStyle(
                  //     fontSize: 15,
                  //     color: Colors.yellow,
                  //     fontWeight: FontWeight.normal),
                  porfileImageUrl: "https://picsum.photos/201",
                  groupTags: const ["#Health And Fitness"],
                  groupTagsStyle: const TextStyle(color: Colors.indigo),
                  groupsList: feedGroupsArraySimple,
                  descriptionStyle: const TextStyle(color: Colors.grey),
                  headingStyle:
                      const TextStyle(color: Colors.black, fontSize: 15),
                  //iconColor: Colors.yellow,
                  iconBackgroundColor: Colors.indigo.shade50,
                  postType: const [
                    PostType.announcement,
                    PostType.poll,
                    PostType.post
                  ],
                  moreOptions: const [
                    MoreOptions.image,
                    MoreOptions.video,
                    MoreOptions.audio,
                    MoreOptions.button
                  ]),
            ),
          );
        },
        child: const Center(child: Text("CreatePost Screen")),
      );

  TextButton _createGroup() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroup(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Create New Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Screen")));

  TextButton _createGroupCommunity() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroupCommunity(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Create New Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
              heading: "Community Access",
              description: "Choose who can join the community",
              descriptionStyle: const TextStyle(
                  fontWeight: FontWeight.w600,
                  fontSize: 14,
                  color: Colors.grey),
              headingStyle:
                  const TextStyle(fontWeight: FontWeight.w600, fontSize: 16),
              optionDescriptionStyle:
                  const TextStyle(color: Colors.grey, fontSize: 10),
              optionTitleStyle: const TextStyle(color: Colors.black),
              disabledColor: Colors.grey.shade200,
              selectedColor: Colors.red,
              optionIconColor: Colors.green,
              addIconColor: Colors.grey,
              addIconTextStyle: const TextStyle(color: Colors.grey),
              bottomButtonColor: Colors.indigoAccent,
              bottomButtonBorderColor: Colors.indigoAccent,
              bottomButtonStyle:
                  const TextStyle(color: Colors.white, fontSize: 16),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Community Screen")));

  TextButton _createGroupSetting() => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => CreateGroupSetting(
              headerView: HeaderView(
                backgroundColor: Colors.white.withOpacity(0.1),
                leftSideIcon: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: const Icon(
                    Icons.arrow_back_outlined,
                    color: Colors.black,
                  ),
                ),
                header: const Text(
                  "Finish Setting Up Your Group",
                  style: TextStyle(color: Colors.black),
                ),
                headerAlignment: Alignment.centerLeft,
              ),
              upperDescription:
                  "Your group is almost ready! Just a few things we thought you may wan to do",
              lowerDescription:
                  "In a rush? You can always do these things later",
              descriptionStyle: const TextStyle(
                  fontWeight: FontWeight.w600,
                  fontSize: 16,
                  color: Colors.grey),
            ),
          ),
        );
      },
      child: const Center(child: Text("CreateGroup Setting Screen")));

  TextButton _newsFeed() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => NewsFeed(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    header: const Text(
                      "News Feed",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                  ),
                  feedGroupsArray: feedGroupsArray,
                  feedPostsArray: feedPostsArray,
                  profileDetailsArray: profileDetailsArray,
                  name: "Bilal Shahid",
                  userName: "@bilal_sh",
                  profileImageUrl: "https://picsum.photos/201",
                  groupTags: const ["#Health And Fitness"],
                  groupList: feedGroupsArraySimple,
                  postType: const [
                    PostType.announcement,
                    PostType.poll,
                    PostType.post
                  ],
                  nameStyle: const TextStyle(
                      fontSize: 15,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  userNameStyle: const TextStyle(
                      fontSize: 15,
                      color: Colors.black,
                      fontWeight: FontWeight.normal),
                  groupTagsStyle: const TextStyle(color: Colors.indigo),
                  groupsList: feedGroupsArraySimple,
                  descriptionStyle: const TextStyle(color: Colors.grey),
                  headingStyle:
                      const TextStyle(color: Colors.black, fontSize: 15),
                  //iconColor: Colors.yellow,
                  iconBackgroundColor: Colors.indigo.shade50,
                  moreOptions: const [
                    MoreOptions.image,
                    MoreOptions.video,
                    MoreOptions.audio
                  ],
                  postedTimeStyle: const TextStyle(
                    fontSize: 15,
                    color: Colors.grey,
                  ),
                  feedTitleStyle: const TextStyle(
                      fontSize: 15,
                      color: Colors.black,
                      fontWeight: FontWeight.bold),
                  feedDescriptionStyle:
                      const TextStyle(fontSize: 15, color: Colors.black),
                  feedAudioTitleStyle: const TextStyle(
                      fontSize: 17,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  hintText: "Create a Post...",
                  commentNameStyle: const TextStyle(
                      fontSize: 15,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  commentPostedTimeStyle:
                      const TextStyle(color: Colors.grey, fontSize: 12),
                  commentStyle:
                      const TextStyle(fontSize: 15, color: Colors.black),
                  commentSubmitButtonColor: Colors.blue),
            ),
          );
        },
        child: const Center(child: Text("News Feed Screen")),
      );

  TextButton _myGroups() => TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => MyGroups(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    header: const Text(
                      "My groups",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                  ),
                  groupsList: feedGroupsArraySimple,
                  titleStyle: const TextStyle(
                      color: Colors.black,
                      fontWeight: FontWeight.bold,
                      fontSize: 15),
                  membersStyle: const TextStyle(color: Colors.grey),
                ),
              ));
        },
        child: const Center(child: Text("My groups")),
      );

  TextButton _groups() => TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => Groups(
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    header: const Text(
                      "Groups",
                      style: TextStyle(color: Colors.black),
                    ),
                    headerAlignment: Alignment.centerLeft,
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                  ),
                  groupsList: feedGroupsArray,
                  groupCardButtonColor: Colors.indigoAccent,
                  groupCardButtonStyle: const TextStyle(color: Colors.white),
                  groupCardMembersStyle: const TextStyle(color: Colors.grey),
                  groupCardTitleStyle: const TextStyle(
                      fontSize: 17,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  groupPageAboutStyle:
                      const TextStyle(fontSize: 15, color: Colors.grey),
                  groupPageMembersStyle: const TextStyle(
                      fontSize: 17,
                      fontWeight: FontWeight.bold,
                      color: Colors.black),
                  groupPageStatusStyle:
                      const TextStyle(fontSize: 17, color: Colors.grey),
                  groupPageTitleStyle: const TextStyle(
                    fontSize: 30,
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                  ),
                ),
              ));
        },
        child: const Center(child: Text("Groups")),
      );

  TextButton _discoverGroups() => TextButton(
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => DiscoverGroups(
                headerView: HeaderView(
                  backgroundColor: Colors.white.withOpacity(0.1),
                  header: const Text(
                    "Discover Groups",
                    style: TextStyle(color: Colors.black),
                  ),
                  headerAlignment: Alignment.centerLeft,
                  leftSideIcon: IconButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    icon: const Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black,
                    ),
                  ),
                  rightSideIcon: TextButton(
                    onPressed: () => Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => CreateGroupCommunity(
                          headerView: HeaderView(
                            backgroundColor: Colors.white.withOpacity(0.1),
                            leftSideIcon: IconButton(
                              onPressed: () {
                                Navigator.pop(context);
                              },
                              icon: const Icon(
                                Icons.arrow_back_outlined,
                                color: Colors.black,
                              ),
                            ),
                            header: const Text(
                              "Create New Group",
                              style: TextStyle(color: Colors.black),
                            ),
                            headerAlignment: Alignment.centerLeft,
                          ),
                          heading: "Community Access",
                          description: "Choose who can join the community",
                          descriptionStyle: const TextStyle(
                              fontWeight: FontWeight.w600,
                              fontSize: 14,
                              color: Colors.grey),
                          headingStyle: const TextStyle(
                              fontWeight: FontWeight.w600, fontSize: 16),
                          optionDescriptionStyle:
                              const TextStyle(color: Colors.grey, fontSize: 10),
                          optionTitleStyle:
                              const TextStyle(color: Colors.black),
                          disabledColor: Colors.grey.shade200,
                          selectedColor: Colors.red,
                          optionIconColor: Colors.green,
                          addIconColor: Colors.grey,
                          addIconTextStyle: const TextStyle(color: Colors.grey),
                          bottomButtonColor: Colors.indigoAccent,
                          bottomButtonBorderColor: Colors.indigoAccent,
                          bottomButtonStyle: const TextStyle(
                              color: Colors.white, fontSize: 16),
                        ),
                      ),
                    ),
                    child: Container(
                      decoration: BoxDecoration(
                          border: Border.all(
                            color: Colors.grey,
                          ),
                          borderRadius:
                              const BorderRadius.all(Radius.circular(20))),
                      margin: const EdgeInsets.symmetric(horizontal: 10),
                      height: 30,
                      width: 75,
                      alignment: Alignment.center,
                      child: Row(
                        children: const [
                          Icon(
                            Icons.add,
                            color: Colors.black,
                          ),
                          Text("Create",
                              textAlign: TextAlign.center,
                              style: TextStyle(color: Colors.black)),
                        ],
                      ),
                    ),
                  ),
                ),
                groupsList: feedGroupsArray,
                groupCardButtonColor: Colors.indigoAccent,
                groupCardButtonStyle: const TextStyle(color: Colors.white),
                groupCardMembersStyle: const TextStyle(color: Colors.grey),
                groupCardTitleStyle: const TextStyle(
                    fontSize: 20,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                groupPageAboutStyle:
                    const TextStyle(fontSize: 15, color: Colors.grey),
                groupPageMembersStyle: const TextStyle(
                    fontSize: 17,
                    fontWeight: FontWeight.bold,
                    color: Colors.black),
                groupPageStatusStyle:
                    const TextStyle(fontSize: 17, color: Colors.grey),
                groupPageTitleStyle: const TextStyle(
                  fontSize: 30,
                  fontWeight: FontWeight.bold,
                  color: Colors.black,
                ),
                avatarSize: 10,
                groupCardHeight: 300,
              ),
            ),
          );
        },
        child: const Center(child: Text("Discover Groups")),
      );

  @override
  Widget build(BuildContext context) => Scaffold(
        body: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            _profileOverview(),
            _createPost(),
            _newsFeed(),
            //_createGroup(),
            _createGroupCommunity(),
            _createGroupSetting(),
            _myGroups(),
            _discoverGroups(),
            //_groups()
          ],
        ),
      );
}

List<ProfileProperties> profileDetailsArray = [
  const ProfileProperties(
    propertyName: "City",
    propertyValue: "Islamabad",
  ),
  const ProfileProperties(
    propertyName: "Email",
    propertyValue: "bilal.shahid@kitcod.com",
  ),
  const ProfileProperties(
    propertyName: "About",
    propertyValue: "Flutter Developer",
  ),
];

List<FeedGroup> feedGroupsArraySimple = [
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/200",
    groupTitle: "#Health And Fitness",
    members: "188k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/201",
    groupTitle: "#People of Wisdom",
    members: "321k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/202",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/203",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/204",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/205",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/206",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/207",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/208",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
  const FeedGroup(
    groupImageUrl: "https://picsum.photos/209",
    groupTitle: "#Prayers and Wishes",
    members: "892k members",
    membersImageUrls: [
      "https://picsum.photos/200",
      "https://picsum.photos/201",
      "https://picsum.photos/202",
      "https://picsum.photos/203",
      "https://picsum.photos/204",
      "https://picsum.photos/205",
      "https://picsum.photos/206"
    ],
  ),
];

List<FeedGroup> feedGroupsArray = [
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Health And Fitness",
      // buttonColor: Colors.black,
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      isJoined: true,
      groupStatus: "Open group",
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
        FeedPost(
            profileImageUrl: "https://picsum.photos/202",
            groupTags: ["#Health And Fitness"],
            name: "Harry Potter",
            username: "@hp_90",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
            postedTime: "10m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            feedVideoUrl:
                "https://flutter.github.io/assets-for-api-docs/assets/videos/butterfly.mp4",
            feedWebsiteUrl: "www.google.com",
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Health And Fitness",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/200",
      groupTitle: "#Health And Fitness",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/201",
      groupTitle: "#Peopple of Wisdom",
      members: "321k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/202",
      groupTitle: "#Justice & Love",
      members: "125 members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/203",
      groupTitle: "#Prayers and Wishes",
      members: "12k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              )
            ]),
      ]),
  const FeedGroup(
      groupImageUrl: "https://picsum.photos/204",
      groupTitle: "#People and games",
      members: "129k members",
      membersImageUrls: [
        "https://picsum.photos/200",
        "https://picsum.photos/201",
        "https://picsum.photos/202",
        "https://picsum.photos/203",
        "https://picsum.photos/204",
        "https://picsum.photos/205",
        "https://picsum.photos/206"
      ],
      groupStatus: "Open group",
      isJoined: false,
      groupAbout:
          "This has enabled our product teams to ship new products faster and feel more.",
      groupPosts: [
        FeedPost(
            feedImageUrl: "https://picsum.photos/200",
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            description:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            commentsList: [
              Comment(
                profileImageUrl: "https://picsum.photos/201",
                groupTags: ["#Health And Fitness"],
                name: "Bilal Shahid",
                username: "@bilal_sh",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
                replies: [
                  CommentReply(
                      comment: "Hi",
                      name: "Mohd",
                      profileImageUrl: "https://picsum.photos/202",
                      postedTime: "A moment ago"),
                ],
              ),
              Comment(
                profileImageUrl: "https://picsum.photos/202",
                groupTags: ["#Health And Fitness"],
                name: "Hsrdik Pandya",
                username: "@hhd007",
                comment:
                    "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
                postedTime: "2m ago",
                likes: 90,
                comments: 80,
                shares: 66,
              )
            ]),
      ]),
];

List<FeedPost> feedPostsArray = [
  const FeedPost(
      feedImageUrl: "https://picsum.photos/200",
      profileImageUrl: "https://picsum.photos/201",
      groupTags: [
        "#Health And Fitness",
      ],
      name: "Bilal Shahid",
      username: "@bilal_sh",
      feedTitle: "9 Simple Dips for your healthy guests",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more. ",
      postedTime: "2m ago",
      likes: 90,
      comments: 80,
      shares: 66,
      commentsList: [
        Comment(
            profileImageUrl: "https://picsum.photos/201",
            groupTags: ["#Health And Fitness"],
            name: "Bilal Shahid",
            username: "@bilal_sh",
            comment:
                "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
            postedTime: "2m ago",
            likes: 90,
            comments: 80,
            shares: 66,
            replies: [
              CommentReply(
                  comment: "Hi",
                  name: "Mohd",
                  profileImageUrl: "https://picsum.photos/202",
                  postedTime: "A moment ago"),
              CommentReply(
                comment: "Hello",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago",
              ),
              CommentReply(
                  comment: "This post is very informative and interesring.",
                  name: "Bilal",
                  profileImageUrl: "https://picsum.photos/205",
                  postedTime: "A moment ago"),
              CommentReply(
                  comment: "Hello",
                  name: "Mohd",
                  profileImageUrl: "https://picsum.photos/202",
                  postedTime: "A moment ago"),
              CommentReply(
                  comment: "How are you?",
                  name: "Mohd",
                  profileImageUrl: "https://picsum.photos/202",
                  postedTime: "A moment ago"),
              CommentReply(
                  comment:
                      "This post is very informative and interesring.This post is very informative and interesring.This post is very informative and interesring.This post is very informative and interesring.",
                  name: "Mohd",
                  profileImageUrl: "https://picsum.photos/202",
                  postedTime: "A moment ago"),
            ]),
        Comment(
          profileImageUrl: "https://picsum.photos/202",
          groupTags: ["#Health And Fitness"],
          name: "Hsrdik Pandya",
          username: "@hhd007",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/202",
      groupTags: ["#Health And Fitness"],
      name: "Harry Potter",
      username: "@hp_90",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "10m ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedVideoUrl:
          "https://flutter.github.io/assets-for-api-docs/assets/videos/butterfly.mp4",
      feedWebsiteUrl: "www.google.com",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Health And Fitness"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
          replies: [
            CommentReply(
                comment: "Hi",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago"),
            CommentReply(
              comment: "Hello",
              name: "Mohd",
              profileImageUrl: "https://picsum.photos/202",
              postedTime: "A moment ago",
            ),
          ],
        )
      ]),
  const FeedPost(
      feedImageUrl: "https://picsum.photos/202",
      profileImageUrl: "https://picsum.photos/203",
      groupTags: ["#Health And Fitness"],
      name: "Michael Scott",
      username: "@michael99",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Health And Fitness"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
          replies: [
            CommentReply(
                comment: "Hi",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago"),
            CommentReply(
              comment: "Hello",
              name: "Mohd",
              profileImageUrl: "https://picsum.photos/202",
              postedTime: "A moment ago",
            ),
          ],
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Health And Fitness"],
      name: "James Dean",
      username: "@jdean",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedPollDetails: PollDetails(
        creator: "admin",
        currentUser: "bilalshah",
        usersWhoVoted: {
          "test@gmail.com": 1,
          "deny@gmail.com": 3,
          "kent@gmail.com": 2,
          "xyz@gmail.com": 3
        },
        pollTitle: "What creator economy means to you?",
        pollOptions: {
          "Making more money": 1,
          "Bussiness interactions increasing": 3,
          "Showcasing brand value": 2,
        },
      ),
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Health And Fitness"],
          name: "Bilal Shah",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
          replies: [
            CommentReply(
                comment: "Hi",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago"),
            CommentReply(
              comment: "Hello",
              name: "Mohd",
              profileImageUrl: "https://picsum.photos/202",
              postedTime: "A moment ago",
            ),
          ],
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Health And Fitness"],
      name: "James Dean",
      username: "@jdean",
      description:
          "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedWebsiteUrl: "www.google.com",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Health And Fitness"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
          replies: [
            CommentReply(
                comment: "Hi",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago"),
            CommentReply(
              comment: "Hello",
              name: "Mohd",
              profileImageUrl: "https://picsum.photos/202",
              postedTime: "A moment ago",
            ),
          ],
        )
      ]),
  const FeedPost(
      profileImageUrl: "https://picsum.photos/204",
      groupTags: ["#Health And Fitness"],
      name: "James Dean",
      username: "@jdean",
      postedTime: "1h ago",
      likes: 90,
      comments: 80,
      shares: 66,
      feedImageUrl: "https://picsum.photos/204",
      feedAudioTitle: "Beautiful Music - Eric Partaalu",
      feedAudioUrl:
          "https://www.soundhelix.com/examples/mp3/SoundHelix-Song-1.mp3",
      commentsList: [
        Comment(
          profileImageUrl: "https://picsum.photos/201",
          groupTags: ["#Health And Fitness"],
          name: "Bilal Shahid",
          username: "@bilal_sh",
          comment:
              "With this community, everyone works towards a shared goal. This has enabled our product teams to ship new products faster and feel more.",
          postedTime: "2m ago",
          likes: 90,
          comments: 80,
          shares: 66,
          replies: [
            CommentReply(
                comment: "Hi",
                name: "Mohd",
                profileImageUrl: "https://picsum.photos/202",
                postedTime: "A moment ago"),
            CommentReply(
              comment: "Hello",
              name: "Mohd",
              profileImageUrl: "https://picsum.photos/202",
              postedTime: "A moment ago",
            ),
          ],
        )
      ]),
];
