part of kitcod_uikit_flutter;

class BottomSheet extends StatelessWidget {
  const BottomSheet({
    required this.optionsHeading,
    this.iconColor,
    this.iconBackgroundColor,
    this.headingStyle,
    this.descriptionStyle,
    this.postType,
    this.moreOptions,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final Text optionsHeading;
  final Color? iconColor;
  final Color? iconBackgroundColor;
  final TextStyle? headingStyle;
  final TextStyle? descriptionStyle;
  final List<PostType>? postType;
  final List<MoreOptions>? moreOptions;

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  TextButton build(final BuildContext context) => TextButton(
        onPressed: () => showModalBottomSheet(
            isScrollControlled: true,
            shape: const RoundedRectangleBorder(
                borderRadius: BorderRadius.vertical(
              top: Radius.circular(20),
            )),
            context: context,
            builder: (final context) => Container(
                padding: const EdgeInsets.all(8),
                child: Wrap(
                  children: [
                    Container(
                      alignment: Alignment.center,
                      child: SizedBox(
                        width: MediaQuery.of(context).size.width * 0.15,
                        height: 3,
                        child: DecoratedBox(
                          decoration:
                              BoxDecoration(color: Colors.indigo.shade100),
                        ),
                      ),
                    ),
                    Padding(
                        padding: const EdgeInsets.all(15),
                        child: optionsHeading),
                    if (postType != null)
                      for (var option in postType!)
                        if (option == PostType.announcement)
                          BottomSheetOption(
                            heading: "Announcement",
                            description: "Priority notifications to followers",
                            icon: KitcodAppIcons.announcement,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          )
                        else if (option == PostType.post)
                          BottomSheetOption(
                            heading: "Post",
                            description: "Standard Post",
                            icon: KitcodAppIcons.post,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          )
                        else if (option == PostType.poll)
                          BottomSheetOption(
                            heading: "Poll",
                            description: "Get opinion from your followers",
                            icon: KitcodAppIcons.poll,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          ),
                    if (moreOptions != null)
                      for (var option in moreOptions!)
                        if (option == MoreOptions.image)
                          BottomSheetOption(
                            heading: "Image",
                            description: "Add multiple images to your post",
                            icon: KitcodAppIcons.photo,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          )
                        else if (option == MoreOptions.video)
                          BottomSheetOption(
                            heading: "Video",
                            description: "Add Video links to your post",
                            icon: KitcodAppIcons.video,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          )
                        else if (option == MoreOptions.audio)
                          BottomSheetOption(
                            heading: "Audio",
                            description: "Add Audio files to your post",
                            icon: KitcodAppIcons.audio,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          )
                        else if (option == MoreOptions.button)
                          BottomSheetOption(
                            heading: "Button",
                            description: "Add a Button to your website or blog",
                            icon: KitcodAppIcons.button,
                            iconColor: iconColor,
                            iconBackgroundColor: iconBackgroundColor,
                            headingStyle: headingStyle,
                            descriptionStyle: descriptionStyle,
                          ),
                  ],
                ))),
        child: Container(
          decoration: BoxDecoration(
              border: Border.all(
                color: Colors.grey,
              ),
              borderRadius: const BorderRadius.all(Radius.circular(20))),
          margin: const EdgeInsets.symmetric(horizontal: 10),
          height: MediaQuery.of(context).size.height * 0.09,
          width: MediaQuery.of(context).size.width,
          child: Padding(
            padding: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                Row(children: [
                  if (postType != null)
                    BottomSheetOption(
                      heading: "Announcement",
                      description: "Priority notifications to followers",
                      icon: KitcodAppIcons.announcement,
                      iconColor: iconColor,
                      iconBackgroundColor: iconBackgroundColor,
                      headingStyle: headingStyle,
                      descriptionStyle: descriptionStyle,
                    ),
                  if (moreOptions != null)
                    BottomSheetOption(
                      heading: "Image",
                      description: "Add multiple images to your post",
                      icon: KitcodAppIcons.photo,
                      iconColor: iconColor,
                      iconBackgroundColor: iconBackgroundColor,
                      headingStyle: headingStyle,
                      descriptionStyle: descriptionStyle,
                    )
                ]),
                const Icon(
                  Icons.keyboard_arrow_down_sharp,
                  textDirection: TextDirection.rtl,
                  color: Colors.black,
                )
              ],
            ),
          ),
        ),
      );
}
