part of kitcod_uikit_flutter;

class CommentWidget extends StatelessWidget {
  const CommentWidget({
    required this.comment,
    required this.commentapi,
    required this.buildContext,
    this.nameStyle,
    this.commentStyle,
    this.postedTimeStyle,
    this.submitButtonColor,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final Comment comment;
  final CommentList commentapi;
  final BuildContext buildContext;
  final TextStyle? nameStyle;
  final TextStyle? commentStyle;
  final TextStyle? postedTimeStyle;
  final Color? submitButtonColor;

  String timeAgo(final String date) {
    final dt = DateTime.parse(date);
    return "${timeago.format(dt, locale: "en_short")} ago";
  }

  // -------------------------------- UI FUNCTION -------------------------------- //
  TextButton commentCard(
          final Comment comment, final BuildContext buildContext) =>
      TextButton(
        onPressed: () {
          showDialog(
            context: buildContext,
            builder: _buildPopupDialog,
          );
        },
        child: Column(
          children: [
            TextButton(
              onPressed: Container.new,
              child: ProfileDetails(
                  name: comment.name,
                  userName: comment.username,
                  profileImageUrl: comment.profileImageUrl,
                  groupTags: comment.groupTags),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 50, right: 10),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(timeAgo(commentapi.createdTs),
                      style: const TextStyle(
                        fontSize: 15,
                        color: Colors.grey,
                      )),
                  Padding(
                    padding: const EdgeInsets.only(top: 10, bottom: 10),
                    child: Text(commentapi.html,
                        style:
                            const TextStyle(fontSize: 15, color: Colors.black)),
                  ),
                  const Text("Reply", style: TextStyle(color: Colors.blue)),
                  ShareStatsIcons(
                      likes: commentapi.interactionSummary == null
                          ? null
                          : commentapi.interactionSummary!
                              .interactionCounts["LIKEOPTION1"],
                      comments: commentapi.interactionSummary == null
                          ? null
                          : commentapi.interactionSummary!
                              .interactionCounts["COMMENTTOT"],
                      views: commentapi.interactionSummary == null
                          ? null
                          : commentapi.interactionSummary!
                              .interactionCounts["VIEWTOT"]),
                  if (comment.replies != null)
                    for (var i = 1; i < comment.replies!.length && i <= 3; i++)
                      CommentDetails(
                          comment: comment.replies![i].comment,
                          name: comment.replies![i].name,
                          profileImageUrl: comment.replies![i].profileImageUrl,
                          postedTime: comment.postedTime,
                          //commentReplies: comment.replies![i].commentReplies,
                          //replyOption: "Reply",
                          commentStyle: commentStyle,
                          nameStyle: nameStyle,
                          postedTimeStyle: postedTimeStyle),
                ],
              ),
            ),
            SizedBox(
              width: MediaQuery.of(buildContext).size.width,
              height: 3,
              child: DecoratedBox(
                decoration: BoxDecoration(color: Colors.indigo.shade50),
              ),
            ),
          ],
        ),
      );

  Widget _buildPopupDialog(final BuildContext context) => AlertDialog(
        insetPadding: const EdgeInsets.all(10),
        contentPadding: EdgeInsets.zero,
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topRight: Radius.circular(10), topLeft: Radius.circular(10)),
        ),
        content: Builder(
          builder: (final context) => SizedBox(
            height: MediaQuery.of(context).size.height * 0.9,
            width: MediaQuery.of(context).size.width * 0.9,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Padding(
                  padding: const EdgeInsets.all(10),
                  child: Row(
                    children: [
                      const Icon(Icons.favorite_border_outlined),
                      const Icon(Icons.brightness_high_rounded),
                      Padding(
                        padding: const EdgeInsets.all(5),
                        child: Text(comment.likes.toString()),
                      )
                    ],
                  ),
                ),
                SizedBox(
                  width: MediaQuery.of(context).size.width,
                  height: 3,
                  child: DecoratedBox(
                    decoration: BoxDecoration(color: Colors.indigo.shade50),
                  ),
                ),
                SizedBox(
                  height: MediaQuery.of(context).size.height * 0.7,
                  child: SingleChildScrollView(
                    child: Column(
                      children: [
                        if (comment.replies != null)
                          for (var reply in comment.replies!)
                            CommentDetails(
                                comment: reply.comment,
                                name: reply.name,
                                profileImageUrl: reply.profileImageUrl,
                                postedTime: comment.postedTime,
                                //commentReplies: reply.commentReplies,
                                //replyOption: "Reply",
                                commentStyle: commentStyle,
                                nameStyle: nameStyle,
                                postedTimeStyle: postedTimeStyle),
                      ],
                    ),
                  ),
                ),
                const Spacer(),
                SizedBox(
                  width: MediaQuery.of(context).size.width,
                  height: 3,
                  child: DecoratedBox(
                    decoration: BoxDecoration(color: Colors.indigo.shade50),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(10),
                  child: Container(
                    alignment: Alignment.centerLeft,
                    height: MediaQuery.of(context).size.height * 0.06,
                    width: MediaQuery.of(context).size.width,
                    decoration: BoxDecoration(
                        color: Colors.grey.shade100,
                        borderRadius:
                            const BorderRadius.all(Radius.circular(20))),
                    child: Padding(
                      padding: const EdgeInsets.only(left: 10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          const Text("Write a friendly comment...",
                              style:
                                  TextStyle(color: Colors.grey, fontSize: 13)),
                          Icon(
                            Icons.arrow_circle_right,
                            color: submitButtonColor ?? Colors.blue,
                            size: 50,
                          )
                        ],
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      );

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => SizedBox(
        child: commentCard(comment, context),
      );
}
