part of kitcod_uikit_flutter;

class FeedPostDetails extends StatelessWidget {
  const FeedPostDetails({
    required this.headerView,
    required this.feedPost,
    required this.feedPostApi,
    this.postedTimeStyle,
    this.feedTitleStyle,
    this.descriptionStyle,
    this.feedAudioTitleStyle,
    this.commentNameStyle,
    this.commentStyle,
    this.commentPostedTimeStyle,
    this.commentSubmitButtonColor,
    this.feedPostsArray,
    this.feedGroupsArray,
    this.profileDetailsArray,
    final Key? key,
  }) : super(key: key);
  // -------------------------------- VARIABLES -------------------------------- //

  final HeaderView headerView;
  final FeedPost feedPost;
  final PostList feedPostApi;
  final TextStyle? postedTimeStyle;
  final TextStyle? feedTitleStyle;
  final TextStyle? descriptionStyle;
  final TextStyle? feedAudioTitleStyle;
  final TextStyle? commentNameStyle;
  final TextStyle? commentStyle;
  final TextStyle? commentPostedTimeStyle;
  final Color? commentSubmitButtonColor;
  final List<FeedPost>? feedPostsArray;
  final List<FeedGroup>? feedGroupsArray;
  final List<ProfileProperties>? profileDetailsArray;

  Future<List<CommentList>> getPostCommentData() async {
    final response = await http
        .get(Uri.https("kitcodendpoint-comments.free.beeceptor.com", ""));
    final jsonData = jsonDecode(response.body);
    final List<CommentList> feedPostComments = [];
    // ignore: avoid_dynamic_calls
    for (final feed in jsonData["_embedded"]["commentList"]) {
      // ignore: avoid_dynamic_calls
      final CommentList feedComments =
          CommentList.fromJson(feed as Map<String, dynamic>);
      feedPostComments.add(feedComments);
    }
    return feedPostComments;
  }

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => Scaffold(
        appBar: headerView,
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.only(bottom: 20, left: 20, right: 20),
            child: Column(
              children: [
                groupTagFollow(feedPost, context),
                FeedPostCard(
                  feedPost: feedPost,
                  feedPostApi: feedPostApi,
                  buildContext: context,
                  descriptionStyle: descriptionStyle,
                  feedAudioTitleStyle: feedAudioTitleStyle,
                  feedTitleStyle: feedTitleStyle,
                  postedTimeStyle: postedTimeStyle,
                  feedGroupsArray: feedGroupsArray,
                  feedPostsArray: feedPostsArray,
                  profileDetailsArray: profileDetailsArray,
                ),
                FutureBuilder(
                  future: getPostCommentData(),
                  // ignore: avoid_types_on_closure_parameters
                  builder: (final context, final snapshot) {
                    if (!snapshot.hasData) {
                      return const Center(child: Text("Loading..."));
                    } else {
                      if (snapshot.hasError) {
                        return Center(child: Text("Error: ${snapshot.error}"));
                      } else {
                        final List<CommentList> commentList =
                            snapshot.data! as List<CommentList>;
                        return ListView.builder(
                          shrinkWrap: true,
                          physics: const NeverScrollableScrollPhysics(),
                          itemCount: commentList.length,
                          itemBuilder: (final context, final i) =>
                              CommentWidget(
                            comment: feedPost.commentsList[0],
                            commentapi: commentList[i],
                            buildContext: context,
                            commentStyle: commentStyle,
                            nameStyle: commentNameStyle,
                            postedTimeStyle: commentPostedTimeStyle,
                            submitButtonColor: commentSubmitButtonColor,
                          ),
                        );
                      }
                    }
                  },
                ),
                const TextBar(hintText: "Write your comment"),
              ],
            ),
          ),
        ),
      );

  // -------------------------------- UI FUNCTION -------------------------------- //
  Widget groupTagFollow(final FeedPost feedPost, final BuildContext context) =>
      Column(
        children: [
          SizedBox(
            width: MediaQuery.of(context).size.width,
            height: 3,
            child: DecoratedBox(
              decoration: BoxDecoration(color: Colors.indigo.shade50),
            ),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: const EdgeInsets.all(10),
                child: Text(
                  feedPost.groupTags[0],
                  style: const TextStyle(fontWeight: FontWeight.bold),
                ),
              ),
              TextButton(
                onPressed: () {},
                child: Container(
                  decoration: BoxDecoration(
                      border: Border.all(
                        color: Colors.grey,
                      ),
                      borderRadius:
                          const BorderRadius.all(Radius.circular(20))),
                  margin: const EdgeInsets.symmetric(horizontal: 10),
                  height: 35,
                  width: 73,
                  alignment: Alignment.center,
                  child: Row(
                    children: const [
                      Icon(
                        Icons.add,
                        color: Colors.black,
                      ),
                      Text("Follow",
                          textAlign: TextAlign.center,
                          style: TextStyle(color: Colors.black)),
                    ],
                  ),
                ),
              )
            ],
          ),
          SizedBox(
            width: MediaQuery.of(context).size.width,
            height: 3,
            child: DecoratedBox(
              decoration: BoxDecoration(color: Colors.indigo.shade50),
            ),
          ),
          const SizedBox(height: 10),
        ],
      );
}
