part of kitcod_uikit_flutter;

class CreateGroupSetting extends StatefulWidget {
  const CreateGroupSetting(
      {required this.headerView,
      required this.upperDescription,
      required this.lowerDescription,
      this.descriptionStyle,
      final Key? key})
      : super(key: key);
  final HeaderView headerView;
  final String upperDescription;
  final String lowerDescription;
  final TextStyle? descriptionStyle;

  @override
  State<CreateGroupSetting> createState() => _CreateGroupSettingState();
}

class _CreateGroupSettingState extends State<CreateGroupSetting> {
  // -------------------------------- VARIABLES -------------------------------- //
  late bool isPublic;

  // -------------------------------- LIFECYCLE FUNCTIONS -------------------------------- //
  @override
  void initState() {
    super.initState();
    isPublic = true;
  }

  // -------------------------------- UI FUNCTIONS -------------------------------- //

  Column _groupText(final String description) => Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            description,
            style: widget.descriptionStyle ??
                const TextStyle(
                    fontWeight: FontWeight.w600,
                    fontSize: 16,
                    color: Colors.grey),
          ),
          const SizedBox(height: 16),
          Column(
            children: const [
              SizedBox(height: 12),
            ],
          )
        ],
      );

  Container _groupOption(final String title, final String description,
          final Icon icon, final Color? iconColor) =>
      Container(
        decoration: BoxDecoration(
            color: Colors.grey.shade200,
            borderRadius: const BorderRadius.all(Radius.circular(10))),
        height: MediaQuery.of(context).size.height * 0.09,
        child: Material(
          color: Colors.transparent,
          child: BottomSheetOption(
            heading: title,
            description: description,
            icon: KitcodAppIcons.announcement,
            iconColor: iconColor ?? Colors.black,
            iconBackgroundColor: iconColor,
            height: 90,
          ),
        ),
      );

  Button _bottomButton() => Button(
      name: "Take me to the group",
      icon: Icons.arrow_forward_sharp,
      width: MediaQuery.of(context).size.width * 0.9,
      backgroundColor: Colors.white,
      borderSide: const BorderSide(color: kUIKitCodAccentColor),
      textStyle: const TextStyle(color: kUIKitCodAccentColor, fontSize: 16),
      onPressed: () {});

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => Scaffold(
        appBar: widget.headerView,
        body: SafeArea(
          child: SingleChildScrollView(
            child: Container(
              padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 20),
              height: MediaQuery.of(context).size.height * 0.82,
              child: Column(
                children: [
                  _groupText(widget.upperDescription),
                  const SizedBox(height: 24),
                  _groupOption(
                      "Add admins",
                      "Bring your team together",
                      const Icon(
                        Icons.shield_moon,
                        color: Colors.white,
                      ),
                      Colors.blueGrey.shade200),
                  const SizedBox(height: 10),
                  _groupOption(
                      "Create Tags",
                      "Setup subgroups or cohorts",
                      const Icon(
                        Icons.person_pin,
                        color: Colors.white,
                      ),
                      Colors.green.shade400),
                  const SizedBox(height: 10),
                  _groupOption(
                      "Share Community",
                      "Share the community on social media",
                      const Icon(
                        Icons.share_outlined,
                        color: Colors.white,
                      ),
                      Colors.blue),
                  const Spacer(),
                  _groupText(
                    widget.lowerDescription,
                  ),
                  _bottomButton()
                ],
              ),
            ),
          ),
        ),
      );
}
