part of kitcod_uikit_flutter;

class CreatePost extends StatelessWidget {
  const CreatePost({
    required this.headerView,
    required this.name,
    required this.userName,
    required this.porfileImageUrl,
    required this.groupTags,
    required this.moreOptions,
    this.postType,
    this.groupsList,
    this.iconColor,
    this.iconBackgroundColor,
    this.headingStyle,
    this.descriptionStyle,
    this.nameStyle,
    this.userNameStyle,
    this.groupTagsStyle,
    final Key? key,
  }) : super(key: key);
  // -------------------------------- VARIABLES -------------------------------- //

  final HeaderView headerView;
  final String name;
  final String userName;
  final String porfileImageUrl;
  final List<String> groupTags;
  final List<FeedGroup>? groupsList;
  final List<PostType>? postType;
  final List<MoreOptions> moreOptions;
  final TextStyle? nameStyle;
  final TextStyle? groupTagsStyle;
  final TextStyle? userNameStyle;
  final TextStyle? headingStyle;
  final TextStyle? descriptionStyle;
  final Color? iconColor;
  final Color? iconBackgroundColor;

  // -------------------------------- UI FUNCTIONS -------------------------------- //

  SizedBox _topWidget(final BuildContext context) => SizedBox(
        width: MediaQuery.of(context).size.width,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            BottomSheet(
              optionsHeading: const Text("Select post type",
                  style: TextStyle(fontSize: 20)),
              postType: postType,
              iconColor: iconColor,
              iconBackgroundColor: iconBackgroundColor,
              headingStyle: headingStyle,
              descriptionStyle: descriptionStyle,
            ),
            ProfileBottomSheet(
              name: name,
              nameStyle: nameStyle,
              userName: userName,
              userNameStyle: userNameStyle,
              profileImageUrl: porfileImageUrl,
              groupsArray: groupsList,
              groupTags: groupTags,
              groupTagsStyle: groupTagsStyle,
              postedToString: "posted to ",
              optionsHeading: const Text("Select a group to post",
                  style: TextStyle(fontSize: 20)),
            )
          ],
        ),
      );

  Container _headingField(final BuildContext context) => Container(
        height: MediaQuery.of(context).size.height * 0.07,
        width: MediaQuery.of(context).size.width,
        color: Colors.white.withOpacity(0.1),
        margin: const EdgeInsets.symmetric(horizontal: 10),
        child: TextFormField(
          decoration: const InputDecoration(
              border: InputBorder.none,
              focusedBorder: InputBorder.none,
              enabledBorder: InputBorder.none,
              errorBorder: InputBorder.none,
              disabledBorder: InputBorder.none,
              contentPadding:
                  EdgeInsets.only(left: 15, bottom: 10, top: 10, right: 15),
              hintText: "Headline",
              hintStyle: TextStyle(fontSize: 20)),
          style: const TextStyle(fontSize: 24, fontWeight: FontWeight.bold),
        ),
      );

  Container _storyField(final BuildContext context) => Container(
        height: MediaQuery.of(context).size.height * 0.34,
        width: MediaQuery.of(context).size.width,
        color: Colors.white.withOpacity(0.1),
        margin: const EdgeInsets.symmetric(horizontal: 10),
        child: Column(
          children: [
            Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                SingleChildScrollView(
                  child: TextFormField(
                    maxLines: 5,
                    decoration: const InputDecoration(
                      border: InputBorder.none,
                      focusedBorder: InputBorder.none,
                      enabledBorder: InputBorder.none,
                      errorBorder: InputBorder.none,
                      disabledBorder: InputBorder.none,
                      contentPadding: EdgeInsets.only(
                          left: 15, top: 10, bottom: 10, right: 15),
                      hintText: "Write your story...",
                      hintStyle: TextStyle(fontSize: 15),
                    ),
                  ),
                ),
              ],
            ),
          ],
        ),
      );

  SizedBox _bottomWidget(final BuildContext context) => SizedBox(
        width: MediaQuery.of(context).size.width,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            BottomSheet(
              optionsHeading:
                  const Text("More options", style: TextStyle(fontSize: 20)),
              moreOptions: moreOptions,
              iconColor: iconColor,
              iconBackgroundColor: iconBackgroundColor,
              headingStyle: headingStyle,
              descriptionStyle: descriptionStyle,
            ),
            Padding(
              padding: const EdgeInsets.only(
                  bottom: 25, left: 25, right: 25, top: 10),
              child: Button(
                name: "Post",
                width: MediaQuery.of(context).size.width,
                onPressed: () {},
                backgroundColor: Colors.indigo,
                textStyle: const TextStyle(color: Colors.white),
              ),
            ),
          ],
        ),
      );

  // -------------------------------- BUILD FUNCTION -------------------------------- //

  @override
  Widget build(final context) => Scaffold(
        appBar: headerView,
        body: SingleChildScrollView(
          child: Column(children: [
            _topWidget(context),
            _headingField(context),
            _storyField(context),
            _bottomWidget(context)
          ]),
        ),
      );
}
