part of kitcod_uikit_flutter;

class NewsFeed extends StatelessWidget {
  const NewsFeed({
    required this.headerView,
    required this.feedGroupsArray,
    required this.feedPostsArray,
    required this.profileDetailsArray,
    required this.name,
    required this.userName,
    required this.profileImageUrl,
    required this.groupTags,
    required this.groupList,
    required this.moreOptions,
    this.hintText,
    this.postType,
    this.nameStyle,
    this.userNameStyle,
    this.groupTagsStyle,
    this.groupsList,
    this.iconColor,
    this.iconBackgroundColor,
    this.headingStyle,
    this.descriptionStyle,
    this.hintTextStyle,
    this.icon,
    this.postedTimeStyle,
    this.feedTitleStyle,
    this.feedDescriptionStyle,
    this.feedAudioTitleStyle,
    this.commentNameStyle,
    this.commentStyle,
    this.commentPostedTimeStyle,
    this.commentSubmitButtonColor,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //

  final HeaderView headerView;
  final List<FeedGroup> feedGroupsArray;
  final List<FeedPost> feedPostsArray;
  final List<ProfileProperties>? profileDetailsArray;
  final String name;
  final String userName;
  final String profileImageUrl;
  final String? hintText;
  final List<String> groupTags;
  final List<FeedGroup> groupList;
  final TextStyle? hintTextStyle;
  final IconData? icon;
  final Color? iconColor;
  final List<PostType>? postType;
  final List<FeedGroup>? groupsList;
  final List<MoreOptions> moreOptions;
  final TextStyle? nameStyle;
  final TextStyle? groupTagsStyle;
  final TextStyle? userNameStyle;
  final TextStyle? headingStyle;
  final TextStyle? descriptionStyle;
  final Color? iconBackgroundColor;
  final TextStyle? postedTimeStyle;
  final TextStyle? feedTitleStyle;
  final TextStyle? feedDescriptionStyle;
  final TextStyle? feedAudioTitleStyle;
  final TextStyle? commentNameStyle;
  final TextStyle? commentStyle;
  final TextStyle? commentPostedTimeStyle;
  final Color? commentSubmitButtonColor;

  // -------------------------------- UI FUNCTIONS -------------------------------- //

  SizedBox _feedWidget(final BuildContext context) => SizedBox(
        width: MediaQuery.of(context).size.width,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            TextBarButton(
              name: name,
              hintText: hintText ?? "Create a Post...",
              userName: userName,
              profileImageUrl: profileImageUrl,
              groupTags: groupTags,
              groupList: groupList,
              postType: postType ??
                  [PostType.announcement, PostType.poll, PostType.post],
              groupsList: feedGroupsArray,
              moreOptions: moreOptions,
              nameStyle: nameStyle,
              userNameStyle: userNameStyle,
              iconColor: iconColor,
              descriptionStyle: descriptionStyle,
              groupTagsStyle: groupTagsStyle,
              headingStyle: headingStyle,
              hintTextStyle: hintTextStyle,
              iconBackgroundColor: iconBackgroundColor,
            ),
            GroupsList(
              feedGroupsArray: feedGroupsArray,
            ),
            SizedBox(
              width: MediaQuery.of(context).size.width,
              height: 3,
              child: DecoratedBox(
                decoration: BoxDecoration(color: Colors.indigo.shade50),
              ),
            ),
            FeedPostsList(
                feedPostsArray: feedPostsArray,
                feedGroupsArray: feedGroupsArray,
                nameStyle: nameStyle,
                userNameStyle: userNameStyle,
                groupTagsStyle: groupTagsStyle,
                descriptionStyle: feedDescriptionStyle,
                feedAudioTitleStyle: feedAudioTitleStyle,
                feedTitleStyle: feedTitleStyle,
                postedTimeStyle: postedTimeStyle,
                commentNameStyle: commentNameStyle,
                commentPostedTimeStyle: commentPostedTimeStyle,
                commentStyle: commentStyle,
                commentSubmitButtonColor: commentSubmitButtonColor,
                profileDetailsArray: profileDetailsArray),
          ],
        ),
      );

  // -------------------------------- BUILD FUNCTION -------------------------------- //

  @override
  Widget build(final context) => Scaffold(
        appBar: headerView,
        body: SingleChildScrollView(
          child: Column(children: [
            _feedWidget(context),
          ]),
        ),
        floatingActionButton: FloatingActionButton(
            onPressed: () => showModalBottomSheet(
                  isScrollControlled: true,
                  shape: const RoundedRectangleBorder(
                      borderRadius: BorderRadius.vertical(
                    top: Radius.circular(20),
                  )),
                  context: context,
                  builder: (final context) => Container(
                      padding: const EdgeInsets.all(8),
                      child: BottomSheetDropdown(
                        heading: "Select post type",
                        groupList: groupList,
                        postType: postType ??
                            [
                              PostType.announcement,
                              PostType.poll,
                              PostType.post
                            ],
                        iconColor: iconColor,
                        iconBackgroundColor: iconBackgroundColor,
                        headingStyle: headingStyle,
                        descriptionStyle: descriptionStyle,
                        nameStyle: nameStyle,
                        groupTagsStyle: groupTagsStyle,
                        userNameStyle: userNameStyle,
                        groupTags: groupTags,
                        hintText: hintText!,
                        icon: icon,
                        moreOptions: moreOptions,
                        name: name,
                        profileImageUrl: profileImageUrl,
                        userName: userName,
                        groupsList: groupList,
                        hintTextStyle: hintTextStyle,
                      )),
                ),
            child: const Icon(Icons.add_outlined)),
        floatingActionButtonLocation: FloatingActionButtonLocation.endFloat,
      );
}
