part of kitcod_uikit_flutter;

class UserProfileView extends StatelessWidget {
  const UserProfileView({
    required this.headerView,
    required this.profileImageUrl,
    required this.name,
    required this.profileDetailsArray,
    required this.button,
    required this.groupsList,
    required this.feedPostsArray,
    this.groupCardWidth,
    this.groupCardHeight,
    this.avatarSize,
    this.groupCardTitleStyle,
    this.groupCardMembersStyle,
    this.groupCardButtonColor,
    this.groupCardButtonStyle,
    this.groupPageTitleStyle,
    this.groupPageMembersStyle,
    this.groupPageStatusStyle,
    this.groupPageAboutStyle,
    this.nameStyle,
    this.profileDetailsNameStyle,
    this.profileDetailsValueStyle,
    this.postNameStyle,
    this.postUserNameStyle,
    this.postGroupTagsStyle,
    this.postFeedDescriptionStyle,
    this.postFeedAudioTitleStyle,
    this.postFeedTitleStyle,
    this.postPostedTimeStyle,
    final Key? key,
  }) : super(key: key);
  // -------------------------------- VARIABLES -------------------------------- //

  final HeaderView headerView;
  final String name;
  final String profileImageUrl;
  final TextStyle? nameStyle;
  final TextStyle? profileDetailsNameStyle;
  final TextStyle? profileDetailsValueStyle;
  final List<ProfileProperties> profileDetailsArray;
  final List<FeedGroup> groupsList;
  final Button button;
  final double? groupCardWidth;
  final double? groupCardHeight;
  final double? avatarSize;
  final TextStyle? groupCardTitleStyle;
  final TextStyle? groupCardMembersStyle;
  final TextStyle? groupCardButtonStyle;
  final Color? groupCardButtonColor;
  final TextStyle? groupPageTitleStyle;
  final TextStyle? groupPageMembersStyle;
  final TextStyle? groupPageStatusStyle;
  final TextStyle? groupPageAboutStyle;
  final List<FeedPost> feedPostsArray;
  final TextStyle? postNameStyle;
  final TextStyle? postGroupTagsStyle;
  final TextStyle? postUserNameStyle;
  final TextStyle? postFeedDescriptionStyle;
  final TextStyle? postFeedAudioTitleStyle;
  final TextStyle? postFeedTitleStyle;
  final TextStyle? postPostedTimeStyle;

  Future<UserProfile> getUserProfileData() async {
    final response = await http
        .get(Uri.https("kitcodendpoint-user-profile.free.beeceptor.com", ""));
    final jsonData = jsonDecode(response.body);
    final UserProfile userProfile =
        UserProfile.fromJson(jsonData as Map<String, dynamic>);
    return userProfile;
  }

  Future<List<Communities>> getGroupsData() async {
    final response = await http
        .get(Uri.https("kitcodendpoint-groups.free.beeceptor.com", ""));
    final jsonData = jsonDecode(response.body);
    final List<Communities> groupsApis = [];
    // ignore: avoid_dynamic_calls
    for (final feed in jsonData) {
      // ignore: avoid_dynamic_calls
      final Communities feedPost =
          Communities.fromJson(feed as Map<String, dynamic>);
      groupsApis.add(feedPost);
    }
    return groupsApis;
  }

  // -------------------------------- UI FUNCTIONS -------------------------------- //

  Padding _infoWidget(final String title, final TextStyle? titleStyle,
          final String value, final TextStyle? valueStyle) =>
      Padding(
        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 12),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisSize: MainAxisSize.min,
          children: [
            Text(
              title,
              style: titleStyle ?? TextStyle(color: Colors.grey.shade600),
            ),
            const SizedBox(height: 4),
            Text(
              value,
              style: valueStyle ?? const TextStyle(fontWeight: FontWeight.bold),
            ),
          ],
        ),
      );

  Column _headerWidget(final BuildContext context) => Column(
        children: [
          FutureBuilder(
            future: getUserProfileData(),
            // ignore: avoid_types_on_closure_parameters
            builder: (final context, final AsyncSnapshot<Object> snapshot) {
              if (!snapshot.hasData) {
                return const Center(child: Text("Loading..."));
              } else {
                if (snapshot.hasError) {
                  return Center(child: Text("Error: ${snapshot.error}"));
                } else {
                  final UserProfile userProfileResponse =
                      snapshot.data! as UserProfile;
                  return Column(
                    children: [
                      Stack(clipBehavior: Clip.none, children: <Widget>[
                        Container(
                          height: MediaQuery.of(context).size.height * 0.32,
                          width: MediaQuery.of(context).size.width,
                          color: Colors.indigoAccent.withOpacity(0.1),
                          child: Column(
                            children: [
                              CircleAvatar(
                                radius: MediaQuery.of(context).size.width * 0.2,
                                backgroundImage: NetworkImage(
                                    userProfileResponse.media!.proImg!
                                        .resizedMediaList.first.mediaUrl),
                                backgroundColor: Colors.transparent,
                              ),
                              Padding(
                                padding: const EdgeInsets.all(10),
                                child: Text(
                                  "${userProfileResponse.firstName!} ${userProfileResponse.lastName!}",
                                  style: nameStyle ??
                                      const TextStyle(
                                        fontSize: 20,
                                        fontWeight: FontWeight.bold,
                                      ),
                                ),
                              ),
                            ],
                          ),
                        ),
                        Positioned(
                          right: 140,
                          left: 140,
                          bottom: -23,
                          child: button,
                        ),
                      ]),
                      SizedBox(
                        width: MediaQuery.of(context).size.width,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            const SizedBox(height: 8),
                            //for (var profileDetails in profileDetailsArray)
                            _infoWidget(
                                "City",
                                profileDetailsNameStyle,
                                userProfileResponse
                                    .homeLocation!.address!.city!,
                                profileDetailsValueStyle),
                            _infoWidget(
                                "Email",
                                profileDetailsNameStyle,
                                userProfileResponse.contactPoints!.first.value!,
                                profileDetailsValueStyle),
                          ],
                        ),
                      )
                    ],
                  );
                }
              }
            },
          ),
        ],
      );

  SizedBox _profileDetailsWidget(final BuildContext context) => SizedBox(
        width: MediaQuery.of(context).size.width,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const SizedBox(height: 8),
            for (var profileDetails in profileDetailsArray)
              _infoWidget(profileDetails.propertyName, profileDetailsNameStyle,
                  profileDetails.propertyValue, profileDetailsValueStyle),
          ],
        ),
      );

  Column _groupsListWidget(final BuildContext context) => Column(
        children: [
          Padding(
            padding: const EdgeInsets.only(top: 20, right: 20, left: 30),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: const [
                Text("My groups",
                    style: TextStyle(
                        color: Colors.black, fontWeight: FontWeight.bold)),
              ],
            ),
          ),
          Row(
            children: [
              FutureBuilder(
                future: getGroupsData(),
                // ignore: avoid_types_on_closure_parameters
                builder: (final context, final snapshot) {
                  if (!snapshot.hasData) {
                    return const Center(child: Text("Loading..."));
                  } else {
                    if (snapshot.hasError) {
                      return Center(child: Text("Error: ${snapshot.error}"));
                    } else {
                      final List<Communities> communitiesList =
                          snapshot.data! as List<Communities>;
                      return SizedBox(
                        height: 350,
                        width: MediaQuery.of(context).size.width,
                        child: ListView.builder(
                          itemExtent: groupCardHeight,
                          scrollDirection: Axis.horizontal,
                          shrinkWrap: true,
                          itemCount: communitiesList.length,
                          itemBuilder: (final context, final i) => GroupCards(
                            groupCardWidth: groupCardWidth,
                            groupCardHeight: groupCardHeight,
                            avatarSize: avatarSize,
                            groupImageUrl:
                                communitiesList[i].body.media.proImg == null
                                    ? "https://picsum.photos/201"
                                    : communitiesList[i]
                                        .body
                                        .media
                                        .proImg!
                                        .resizedMediaList
                                        .first
                                        .mediaUrl,
                            groupTitle: communitiesList[i]
                                .body
                                .name, // groupItem.groupTitle,
                            members:
                                communitiesList[i].body.rangeMembersCount ==
                                        null
                                    ? ""
                                    : communitiesList[i]
                                        .body
                                        .rangeMembersCount
                                        .toString(), //groupItem.members,
                            membersListUrl: groupsList[0]
                                .membersImageUrls, //  groupItem.membersImageUrls,
                            groupPageAbout: communitiesList[i]
                                .body
                                .description, //groupItem.groupAbout!,
                            groupPosts: groupsList[0]
                                .groupPosts!, // groupItem.groupPosts!,
                            groupPageStatus:
                                "Open Group", //groupItem.groupStatus!,
                            isJoined: false, // groupItem.isJoined!,
                            groupCardButtonColor: groupCardButtonColor,
                            groupCardButtonStyle: groupCardButtonStyle,
                            groupCardTitleStyle: groupCardTitleStyle,
                            groupCardMembersStyle: groupCardMembersStyle,
                            groupPageAboutStyle: groupPageAboutStyle,
                            groupPageStatusStyle: groupPageStatusStyle,
                            groupPageTitleStyle: groupPageTitleStyle,
                            groupPageMembersStyle: groupPageMembersStyle,
                          ),
                        ),
                      );
                    }
                  }
                },
              ),
            ],
          ),
        ],
      );

  SizedBox _postsWidget(final BuildContext context) => SizedBox(
        width: MediaQuery.of(context).size.width,
        child: Column(
          children: [
            Padding(
              padding: const EdgeInsets.only(top: 10, right: 20, left: 30),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: const [
                  Text("Posts",
                      style: TextStyle(
                          color: Colors.black, fontWeight: FontWeight.bold)),
                ],
              ),
            ),
            FeedPostsList(
              feedPostsArray: feedPostsArray,
              feedGroupsArray: groupsList,
              nameStyle: postNameStyle,
              userNameStyle: postUserNameStyle,
              groupTagsStyle: postGroupTagsStyle,
              descriptionStyle: postFeedDescriptionStyle,
              feedAudioTitleStyle: postFeedAudioTitleStyle,
              feedTitleStyle: postFeedTitleStyle,
              postedTimeStyle: postPostedTimeStyle,
            ),
          ],
        ),
      );

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => Scaffold(
        appBar: headerView,
        body: SingleChildScrollView(
          child: Column(children: [
            _headerWidget(context),
            //_profileDetailsWidget(context),
            _groupsListWidget(context),
            //_postsWidget(context)
          ]),
        ),
      );
}
